@@ -39,10 +39,10 @@ def send_slack(file_to_send, customer_name: str = None):
             initial_comment=f"SD API Uploader log files for {customer_name}"
         )
 
-        # logger.log(message=f"Slack response: {response}", to_file=True, to_terminal=True, log_level='info')
+        logger.log(message=f"Slack response: {response}", to_file=True, to_terminal=True, log_level='info')
         #  if response code is 200, then everything is good, log success
-        if response.status_code == 200:
-            logger.log(message="Slack upload successful", to_file=True, to_terminal=True, log_level='info')
+        # if response.status_code == 200:
+        #     logger.log(message="Slack upload successful", to_file=True, to_terminal=True, log_level='info')
         
     except SlackApiError as e:
         # You will get a SlackApiError if "ok" is False
